@@ -125,7 +125,7 @@ from arjuna.tpi.guiauto.model.dialog import GuiDialog
 from arjuna.tpi.guiauto.helper import Keys
 
 from arjuna.tpi.httpauto.http import Http
-from arjuna.tpi.httpauto.oauth import OAuthImplicitGrantSession
+from arjuna.tpi.httpauto.oauth import OAuthImplicitGrantService
 
 from arjuna.tpi.dbauto.db import DB
 
