@@ -71,6 +71,8 @@ _RAW_OPTION_LEVELS = {
         "SELENIUM_DRIVERS_DIR",
         "SELENIUM_DRIVER_PATH",
         "RUN_ID",
+        "HTTPAUTO_DIR",
+        "HTTPAUTO_MESSAGE_DIR"
     },
 
     ConfigStage.CLI: {
@@ -83,7 +85,10 @@ _RAW_OPTION_LEVELS = {
 
     ConfigStage.PROJECT: {
         "LOG_ALLOWED_CONTEXTS",
-        "DEPS_DIR"
+        "DEPS_DIR",
+        "HTTP_PROXY_ENABLED",
+        "HTTP_PROXY_HOST",
+        "HTTP_PROXY_PORT",
     },
 
     ConfigStage.REFERENCE: {
