@@ -22,15 +22,16 @@ from requests import Request
 from arjuna.tpi.error import HttpRequestCreationError
 from arjuna.tpi.parser.json import Json, JsonDict, JsonList
 from arjuna.tpi.parser.html import Html
+from arjuna.tpi.data.entity import _DataEntity
 from arjuna.tpi.engine.asserter import AsserterMixIn
 import time
 
-from .message import HttpMessage
+from .packet import HttpPacket
 from .response import HttpResponse
 
-class HttpRequest(HttpMessage):
+class HttpRequest(HttpPacket):
     '''
-        Encapsulates HTTP response message.
+        Encapsulates HTTP request packet.
 
         Arguments:
             session: `HttpSession` object which created this `HttpRequest`.
@@ -39,13 +40,12 @@ class HttpRequest(HttpMessage):
         Keyword Arguments:
             label: Label for this request. If available, it is used in Reports and logs.
             xcodes: Expected Status Code(s)
-            strict: If True in case of unexpected status code, an AssertionError is raised, else HttpUnexpectedStatusCodeError is raised.
             allow_redirects: If True, redirections are allowed for the HTTP message. Default is True.
             timeout: How long to wait for the server to send data before giving up.
             cookies: Cookie dictionary
     '''
 
-    def __init__(self, session, request, label=None, xcodes=None, strict=False, allow_redirects=True, timeout=None, cookies=None):
+    def __init__(self, session, request, label=None, xcodes=None, allow_redirects=True, timeout=None, cookies=None):
         super().__init__(request)
         self.__session = session
         self.__request = request
@@ -54,7 +54,6 @@ class HttpRequest(HttpMessage):
         printable_label = label and self.__label + "::" + req_repr or req_repr
         printable_label = len(printable_label) > 119 and printable_label[:125] + "<SNIP>" or printable_label
         self.__label = printable_label
-        self.__strict = strict
         self.__allow_redirects = allow_redirects
         self.__timeout = timeout
         self.__cookies = cookies
@@ -112,22 +111,21 @@ class HttpRequest(HttpMessage):
         '''
         return self.__xcodes
 
-    @property
-    def strict(self) -> bool:
-        '''
-        True if sending this request should raise an Assertion error in case of unexpected status code.
-        '''
-        return self.__strict
-
     @property
     def text(self):
         '''
-            Content of this request message as plain text.
+            Content of this request message as Text object.
+        '''
+        from arjuna.tpi.parser.text import Text
+        return Text(self.content)
+
+    @property
+    def content(self):
+        '''
+            Content of this request message as plain unformatted text.
         '''
         return self.__request.body
 
-    content = text
-
     __OUT ='''{}
 {}{}'''
 
@@ -144,7 +142,7 @@ class HttpRequest(HttpMessage):
         ).strip()
 
     def __str__(self):
-        content = self.text
+        content = self.content
         if isinstance(content, bytes):
             content = content.decode()
         return self.repr_as_str(
@@ -157,19 +155,19 @@ class HttpRequest(HttpMessage):
 
 class _HttpRequest(HttpRequest):
 
-    def __init__(self, session, url, method, label=None, content=None, xcodes=None, strict=False, headers=None, cookies=None, allow_redirects=True, auth=None, timeout=None, pretty_url=False, query_params=None, **named_query_params):
+    def __init__(self, session, url, method, label=None, content=None, xcodes=None, headers=None, cookies=None, allow_redirects=True, auth=None, timeout=None, pretty_url=False, query_params=None, **named_query_params):
         self.__session = session
         self.__method = method.upper()
         self.__url = url
         self.__content = None
         if content is not None:
-            if type(content) in {str, dict, list, tuple} or isinstance(content, JsonDict) or isinstance(content, JsonList):
+            if type(content) in {str, dict, list, tuple} or isinstance(content, JsonDict) or isinstance(content, JsonList) or isinstance(content, _DataEntity):
                 self.__content = self.__session.request_content_handler(content)
             else:
                 self.__content = content
         self.__xcodes = None
         if xcodes is not None:
-            self.__xcodes = type(xcodes) in {set, list, tuple} and xcodes or {xcodes}
+            self.__xcodes = self._process_codes(xcodes)
         self.__query_params = query_params
         if self.__query_params is None:
             self.__query_params = dict()
@@ -186,7 +184,11 @@ class _HttpRequest(HttpRequest):
         self.__auth = auth is not None and auth or self.__session.auth
         self.__prepare_headers()
         self.__req = self.__build_request()
-        super().__init__(self.__session, self.__req, label=label, xcodes=self.__xcodes, strict=strict, allow_redirects=allow_redirects, timeout=timeout, cookies=self.__cookies)
+        super().__init__(self.__session, self.__req, label=label, xcodes=self.__xcodes, allow_redirects=allow_redirects, timeout=timeout, cookies=self.__cookies)
+
+    @classmethod
+    def _process_codes(cls, codes):
+        return type(codes) in {set, list, tuple} and codes or {int(codes)}
 
     def __prepare_headers(self):
         if self.__method in {'POST', 'PUT', 'PATCH', 'OPTIONS'}:
@@ -211,7 +213,7 @@ class _HttpRequest(HttpRequest):
                 data = self.__content.content
             else:
                 data = None
-            req = Request(self.__method, url, data=data, headers=self.__headers, params=query_params, cookies=self.__cookies, auth=self.__auth)
+            req = Request(self.__method, url, data=data, headers={h:v for h,v in self.__headers.items() if v is not None}, params=query_params, cookies=self.__cookies, auth=self.__auth)
             return req.prepare()
         except Exception as e:
             raise HttpRequestCreationError("{} : {}".format(e.__class__.__name__, str(e)))
